@@ -1,10 +1,11 @@
 #' Download a Java distribution
 #'
-#' @param version `Integer` or `character` vector of length 1 for major version of Java to download or install. If not specified, defaults to the latest LTS version. Can be "8", "11", "17", "21", "22", or 8, 11, 17, 21, or 22.
+#' @param version `Integer` or `character` vector of length 1 for major version of Java to download or install. If not specified, defaults to the latest LTS version. Can be "8", and "11" to "24" (or the same version numers in `integer`) or any newer version if it is available for the selected distribution. For `macOS` on `aarch64` architecture (Apple Silicion) certain `Java` versions are not available.
 #' @param distribution The Java distribution to download. If not specified, defaults to "Amazon Corretto". Currently only \href{https://aws.amazon.com/corretto/}{"Amazon Corretto"} is supported.
 #' @param cache_path The destination directory to download the Java distribution to. Defaults to a user-specific data directory.
 #' @param platform The platform for which to download the Java distribution. Defaults to the current platform.
 #' @param arch The architecture for which to download the Java distribution. Defaults to the current architecture.
+#' @param force A logical. Whether the distribution file should be overwritten or not. Defaults to `FALSE`.
 #' @param temp_dir A logical. Whether the file should be saved in a temporary directory. Defaults to `FALSE`.
 #' @inheritParams global_quiet_param
 #'
@@ -13,10 +14,10 @@
 #'
 #' @examples
 #' \dontrun{
-#' 
+#'
 #' # download distribution of Java version 17
 #' java_download(version = "17", temp_dir = TRUE)
-#' 
+#'
 #' # download default Java distribution (version 21)
 #' java_download(temp_dir = TRUE)
 #' }
@@ -27,9 +28,34 @@ java_download <- function(
   platform = platform_detect()$os,
   arch = platform_detect()$arch,
   quiet = FALSE,
+  force = FALSE,
   temp_dir = FALSE
 ) {
-  
+  # Download distribution and check MD5 checksum
+  download_dist_check_md5 <- function(url, dest_file, quiet) {
+    curl::curl_download(url, dest_file, quiet = FALSE)
+    curl::curl_download(url_md5, dest_file_md5, quiet = TRUE)
+
+    if (!quiet) {
+      cli::cli_inform("Download completed.", .envir = environment())
+    }
+    md5sum <- tools::md5sum(dest_file)
+    md5sum_expected <- readLines(dest_file_md5, warn = FALSE)
+
+    if (md5sum != md5sum_expected) {
+      cli::cli_abort(
+        "MD5 checksum mismatch. Please try downloading the file again.",
+        .envir = environment()
+      )
+      unlink(dest_file)
+      return(NULL)
+    } else {
+      if (!quiet) {
+        cli::cli_inform("MD5 checksum verified.", .envir = environment())
+      }
+    }
+  }
+
   # override cache_path if temp_dir is set to TRUE
   if (temp_dir) {
     temp_dir <- tempdir()
@@ -50,7 +76,14 @@ java_download <- function(
   # Checks for the parameters
   checkmate::check_vector(version, len = 1)
   version <- as.character(version)
-  checkmate::assert_choice(version, getOption("rJavaEnv.valid_major_java_versions"))
+  checkmate::assert_choice(
+    as.character(version),
+    java_valid_versions(
+      distribution = distribution,
+      platform = platform,
+      arch = arch
+    )
+  )
 
   checkmate::assert_choice(distribution, valid_distributions)
 
@@ -64,6 +97,7 @@ java_download <- function(
   checkmate::assert_choice(platform, valid_platforms)
   checkmate::assert_choice(arch, valid_architectures)
   checkmate::assert_flag(quiet)
+  checkmate::assert_flag(force)
 
   # Print out the detected platform and architecture
   if (!quiet) {
@@ -75,15 +109,24 @@ java_download <- function(
   }
 
   if (!distribution %in% names(java_urls)) {
-    cli::cli_abort("Unsupported distribution: {.val {distribution}}", .envir = environment())
+    cli::cli_abort(
+      "Unsupported distribution: {.val {distribution}}",
+      .envir = environment()
+    )
   }
 
   if (!platform %in% names(java_urls[[distribution]])) {
-    cli::cli_abort("Unsupported platform: {.val {platform}}", .envir = environment())
+    cli::cli_abort(
+      "Unsupported platform: {.val {platform}}",
+      .envir = environment()
+    )
   }
 
   if (!arch %in% names(java_urls[[distribution]][[platform]])) {
-    cli::cli_abort("Unsupported architecture: {.val {arch}}", .envir = environment())
+    cli::cli_abort(
+      "Unsupported architecture: {.val {arch}}",
+      .envir = environment()
+    )
   }
 
   url_template <- java_urls[[distribution]][[platform]][[arch]]
@@ -93,33 +136,31 @@ java_download <- function(
   dest_file <- file.path(cache_path, basename(url))
   dest_file_md5 <- paste0(file.path(cache_path, basename(url_md5)), ".md5")
 
-
   if (!quiet) {
-    cli::cli_inform("Downloading Java {version} ({distribution}) for {platform} {arch} to {dest_file}", .envir = environment())
+    cli::cli_inform(
+      "Downloading Java {version} ({distribution}) for {platform} {arch} to {dest_file}",
+      .envir = environment()
+    )
   }
 
-  if (file.exists(dest_file)) {
+  if (file.exists(dest_file) & !force) {
     if (!quiet) {
-      cli::cli_inform("File already exists. Skipping download.", .envir = environment())
-    }
-  } else {
-    curl::curl_download(url, dest_file, quiet = FALSE)
-    curl::curl_download(url_md5, dest_file_md5, quiet = TRUE)
-    if (!quiet) {
-      cli::cli_inform("Download completed.", .envir = environment())
-
-      md5sum <- tools::md5sum(dest_file)
-      md5sum_expected <- readLines(dest_file_md5, warn = FALSE)
-
-      if (md5sum != md5sum_expected) {
-        cli::cli_alert_danger("MD5 checksum mismatch. Please try downloading the file again.", .envir = environment())
-        unlink(dest_file)
-        return(NULL)
-      } else {
-        cli::cli_inform("MD5 checksum verified.", .envir = environment())
-      }
+      cli::cli_inform(
+        "File already exists. Skipping download.",
+        .envir = environment()
+      )
     }
+    return(dest_file)
   }
 
+  if (file.exists(dest_file) & force) {
+    if (!quiet) {
+      cli::cli_inform("Removing existing installation.", .envir = environment())
+    }
+    file.remove(dest_file)
+  }
+
+  download_dist_check_md5(url, dest_file, quiet)
+
   return(dest_file)
 }
